@@ -10,7 +10,7 @@ use Cwd qw(abs_path);
 use Readonly;
 
 # Version.
-our $VERSION = 0.09;
+our $VERSION = 0.10;
 
 # Constants.
 Readonly::Array our @EXPORT_OK => qw(clean err_get err_helper);
@@ -254,13 +254,13 @@ Default value is 50.
  eval { err '1', '2', '3'; };
 
  # Error structure.
- my $err_ar = err_get();
+ my @err = err_get();
 
  # Dump.
  my $dump = Dumpvalue->new;
- $dump->dumpValues($err_ar);
+ $dump->dumpValues(\@err);
 
- # In $err_ar:
+ # In \@err:
  # [
  #         {
  #                 'msg' => [
@@ -299,6 +299,10 @@ L<Error::Pure>,
 L<Error::Pure::AllError>,
 L<Error::Pure::Error>,
 L<Error::Pure::ErrorList>,
+L<Error::Pure::HTTP::AllError>,
+L<Error::Pure::HTTP::Error>,
+L<Error::Pure::HTTP::ErrorList>,
+L<Error::Pure::HTTP::Print>,
 L<Error::Pure::Output::Text>,
 L<Error::Pure::Print>.
 
@@ -318,6 +322,6 @@ BSD license.
 
 =head1 VERSION
 
-0.09
+0.10
 
 =cut
